@@ -40,10 +40,10 @@ class GWENVIEWLIB_EXPORT CropImageOperation : public AbstractImageOperation
 {
 public:
     CropImageOperation(const QRect&);
-    ~CropImageOperation();
+    ~CropImageOperation() override;
 
-    void redo() Q_DECL_OVERRIDE;
-    void undo() Q_DECL_OVERRIDE;
+    void redo() override;
+    void undo() override;
 
 private:
     CropImageOperationPrivate* const d;
